<?php
namespace Zeedhi\DevOps\Util;

use Zeedhi\DevOps\Util\Events\Audit\Environment as Audit;
use Zeedhi\DevOps\Util\Events\Organization\Environment as Organization;
use Zeedhi\Framework\ORM\DateTime;
use Zeedhi\Framework\Session\Session;
use Teknisa\Libs\Util\Environment as LibEnvironment;
use Zeedhi\Framework\DependencyInjection\InstanceManager;

class Environment extends LibEnvironment implements Audit, Organization {

    /** @var Session */
    protected $session;
    protected $attachmentsBaseDir;
    protected $pmClientId;
    protected $pmClientSecret;
    protected $pmUrl;
    /**
     * @var
     */
    private $identityUrl;

    public function __construct(Session $session, $attachmentsBaseDir, $pmClientId, $pmClientSecret, $pmUrl, $identityUrl) {
        $this->session = $session;
        $this->attachmentsBaseDir = $attachmentsBaseDir;
        $this->pmClientId = $pmClientId;
        $this->pmClientSecret = $pmClientSecret;
        $this->pmUrl = $pmUrl;
        $this->identityUrl = $identityUrl;
    }

    public function setCurrentUserId($userId) {
        $this->session->set("userId", $userId);
    }

    public function getCurrentUserId() {
        return $this->session->has("userId") ? $this->session->get("userId") : null;
    }

    public function getCurrentCdoperador() {
        return $this->session->has("USER_ID") ? $this->session->get("USER_ID") : null;
    }

    public function setCurrentUserExternalId($userId) {
        $this->session->set("externalUserId", $userId);
    }

    public function getCurrentExternalUserId() {
        return $this->session->has("externalUserId") ? $this->session->get("externalUserId") : null;
    }

    public function getCurrentPmResourceId()
    {
        return $this->session->has("resourceId") ? $this->session->get("resourceId") : null;
    }

    public function getUserId() {
        return $this->getCurrentCdoperador();
    }

    public function setOrganizationId($organizationId) {
        $this->session->set("organizationId", $organizationId);
    }

    public function getOrganizationId() {
        return $this->session->has("organizationId") ? $this->session->get("organizationId") : null;
    }

    public function getCurrentOrganizationId() {
        return $this->getOrganizationId();
    }

    public function getCurrentTime() {
        return new DateTime();
    }

    public function getProjectId() {
        return 5;
    }

    public function getProjectUniqueId() {
        return "DevOps_5";
    }

    public function getContainersJsonPath () {
        return "../../mobile/json/containers.json";
    }

    public function getJsonsDirectories () {
        return array("../../mobile/json/containers");
    }

    public function getToken () {
        return $this->session->get("token");
    }

    public function getAttachmentsBaseDir()
    {
        return $this->attachmentsBaseDir;
    }

    public function getPmClientId()
    {
        return $this->pmClientId;
    }

    public function getPmClientSecret()
    {
        return $this->pmClientSecret;
    }

    public function getPmUrl()
    {
        return $this->pmUrl;
    }

    public function getIdentityUrl()
    {
        return $this->identityUrl;
    }

    public function setToken ($token) {
        $this->session->set("token", $token);
    }

    public function getTokenPM () {
        return $this->session->get("tokenPM");
    }

    public function setTokenPM ($token) {
        $this->session->set("tokenPM", $token);
    }

    public static function getCurrentUserIdDevOps(){
        return InstanceManager::getInstance()->getParameter('currentUserIdDevOps');
    }

    public static function getCurrentOrganizationIdDevOps(){
        return InstanceManager::getInstance()->getParameter('currentOrganizationIdDevOps');
    }
}